# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/data/scanline.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..data import point_pb2 as blickfeld_dot_data_dot_point__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/data/scanline.proto',
  package='blickfeld.protocol.data',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1d\x62lickfeld/data/scanline.proto\x12\x17\x62lickfeld.protocol.data\x1a\x1a\x62lickfeld/data/point.proto\"q\n\x08Scanline\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08\x66rame_id\x18\x02 \x01(\x04\x12.\n\x06points\x18\x03 \x03(\x0b\x32\x1e.blickfeld.protocol.data.Point\x12\x17\n\x0fstart_offset_ns\x18\x04 \x01(\x04')
  ,
  dependencies=[blickfeld_dot_data_dot_point__pb2.DESCRIPTOR,])




_SCANLINE = _descriptor.Descriptor(
  name='Scanline',
  full_name='blickfeld.protocol.data.Scanline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blickfeld.protocol.data.Scanline.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='blickfeld.protocol.data.Scanline.frame_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='blickfeld.protocol.data.Scanline.points', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_offset_ns', full_name='blickfeld.protocol.data.Scanline.start_offset_ns', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=199,
)

_SCANLINE.fields_by_name['points'].message_type = blickfeld_dot_data_dot_point__pb2._POINT
DESCRIPTOR.message_types_by_name['Scanline'] = _SCANLINE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Scanline = _reflection.GeneratedProtocolMessageType('Scanline', (_message.Message,), dict(
  DESCRIPTOR = _SCANLINE,
  __module__ = 'blickfeld.data.scanline_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.Scanline)
  ))
_sym_db.RegisterMessage(Scanline)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/status/scanner.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2
from .. import error_pb2 as blickfeld_dot_error__pb2
from ..config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/status/scanner.proto',
  package='blickfeld.protocol.status',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1e\x62lickfeld/status/scanner.proto\x12\x19\x62lickfeld.protocol.status\x1a\x17\x62lickfeld/options.proto\x1a\x15\x62lickfeld/error.proto\x1a#blickfeld/config/scan_pattern.proto\"\xf4\x02\n\x07Scanner\x12\x37\n\x05state\x18\x01 \x01(\x0e\x32(.blickfeld.protocol.status.Scanner.State\x12\x46\n\x0cscan_pattern\x18\x04 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x08\xb8\xb5\x18\x01\xd0\xb5\x18\x02\x12.\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x19.blickfeld.protocol.ErrorB\x04\xb0\xb5\x18\x01\x12M\n\x13legacy_scan_pattern\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x08\xb8\xb5\x18\x01\xb0\xb5\x18\x01\"i\n\x05State\x12\x10\n\x0cINITIALIZING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07\x45RRORED\x10\x06\x12\r\n\tSELF_TEST\x10\x07')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_error__pb2.DESCRIPTOR,blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,])



_SCANNER_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='blickfeld.protocol.status.Scanner.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READY', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERRORED', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SELF_TEST', index=6, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=414,
  serialized_end=519,
)
_sym_db.RegisterEnumDescriptor(_SCANNER_STATE)


_SCANNER = _descriptor.Descriptor(
  name='Scanner',
  full_name='blickfeld.protocol.status.Scanner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='blickfeld.protocol.status.Scanner.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scan_pattern', full_name='blickfeld.protocol.status.Scanner.scan_pattern', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\270\265\030\001\320\265\030\002'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='blickfeld.protocol.status.Scanner.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_scan_pattern', full_name='blickfeld.protocol.status.Scanner.legacy_scan_pattern', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\270\265\030\001\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCANNER_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=519,
)

_SCANNER.fields_by_name['state'].enum_type = _SCANNER_STATE
_SCANNER.fields_by_name['scan_pattern'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_SCANNER.fields_by_name['error'].message_type = blickfeld_dot_error__pb2._ERROR
_SCANNER.fields_by_name['legacy_scan_pattern'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_SCANNER_STATE.containing_type = _SCANNER
DESCRIPTOR.message_types_by_name['Scanner'] = _SCANNER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Scanner = _reflection.GeneratedProtocolMessageType('Scanner', (_message.Message,), dict(
  DESCRIPTOR = _SCANNER,
  __module__ = 'blickfeld.status.scanner_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.Scanner)
  ))
_sym_db.RegisterMessage(Scanner)


_SCANNER.fields_by_name['scan_pattern']._options = None
_SCANNER.fields_by_name['error']._options = None
_SCANNER.fields_by_name['legacy_scan_pattern']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/stream/connection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2
from ..data import point_cloud_pb2 as blickfeld_dot_data_dot_point__cloud__pb2
from ..status import main_pb2 as blickfeld_dot_status_dot_main__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/stream/connection.proto',
  package='blickfeld.protocol.stream',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n!blickfeld/stream/connection.proto\x12\x19\x62lickfeld.protocol.stream\x1a\x17\x62lickfeld/options.proto\x1a blickfeld/data/point_cloud.proto\x1a\x1b\x62lickfeld/status/main.proto\"\x8e\x02\n\tSubscribe\x12\x46\n\x0bpoint_cloud\x18\x0b \x01(\x0b\x32/.blickfeld.protocol.stream.Subscribe.PointCloudH\x00\x12=\n\x06status\x18\x0c \x01(\x0b\x32+.blickfeld.protocol.stream.Subscribe.StatusH\x00\x12\x43\n\tdeveloper\x18\r \x01(\x0b\x32..blickfeld.protocol.stream.Subscribe.DeveloperH\x00\x1a\x0c\n\nPointCloud\x1a\x08\n\x06Status\x1a\x15\n\tDeveloper*\x08\x08\x01\x10\x80\x80\x80\x80\x02\x42\x06\n\x04\x64\x61ta\"\xd7\x01\n\x05\x45vent\x12:\n\x0bpoint_cloud\x18\x0b \x01(\x0b\x32#.blickfeld.protocol.data.PointCloudH\x00\x12,\n\x06status\x18\x0c \x01(\x0b\x32\x1a.blickfeld.protocol.StatusH\x00\x12?\n\tdeveloper\x18\r \x01(\x0b\x32*.blickfeld.protocol.stream.Event.DeveloperH\x00\x1a\x15\n\tDeveloper*\x08\x08\x01\x10\x80\x80\x80\x80\x02\x42\x0c\n\x04\x64\x61ta\x12\x04\xb0\xb5\x18\x01')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_data_dot_point__cloud__pb2.DESCRIPTOR,blickfeld_dot_status_dot_main__pb2.DESCRIPTOR,])




_SUBSCRIBE_POINTCLOUD = _descriptor.Descriptor(
  name='PointCloud',
  full_name='blickfeld.protocol.stream.Subscribe.PointCloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=382,
)

_SUBSCRIBE_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='blickfeld.protocol.stream.Subscribe.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=392,
)

_SUBSCRIBE_DEVELOPER = _descriptor.Descriptor(
  name='Developer',
  full_name='blickfeld.protocol.stream.Subscribe.Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=415,
)

_SUBSCRIBE = _descriptor.Descriptor(
  name='Subscribe',
  full_name='blickfeld.protocol.stream.Subscribe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point_cloud', full_name='blickfeld.protocol.stream.Subscribe.point_cloud', index=0,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='blickfeld.protocol.stream.Subscribe.status', index=1,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='blickfeld.protocol.stream.Subscribe.developer', index=2,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SUBSCRIBE_POINTCLOUD, _SUBSCRIBE_STATUS, _SUBSCRIBE_DEVELOPER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.stream.Subscribe.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=153,
  serialized_end=423,
)


_EVENT_DEVELOPER = _descriptor.Descriptor(
  name='Developer',
  full_name='blickfeld.protocol.stream.Event.Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=415,
)

_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='blickfeld.protocol.stream.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point_cloud', full_name='blickfeld.protocol.stream.Event.point_cloud', index=0,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='blickfeld.protocol.stream.Event.status', index=1,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='blickfeld.protocol.stream.Event.developer', index=2,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EVENT_DEVELOPER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.stream.Event.data',
      index=0, containing_type=None, fields=[], serialized_options=_b('\260\265\030\001')),
  ],
  serialized_start=426,
  serialized_end=641,
)

_SUBSCRIBE_POINTCLOUD.containing_type = _SUBSCRIBE
_SUBSCRIBE_STATUS.containing_type = _SUBSCRIBE
_SUBSCRIBE_DEVELOPER.containing_type = _SUBSCRIBE
_SUBSCRIBE.fields_by_name['point_cloud'].message_type = _SUBSCRIBE_POINTCLOUD
_SUBSCRIBE.fields_by_name['status'].message_type = _SUBSCRIBE_STATUS
_SUBSCRIBE.fields_by_name['developer'].message_type = _SUBSCRIBE_DEVELOPER
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['point_cloud'])
_SUBSCRIBE.fields_by_name['point_cloud'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['status'])
_SUBSCRIBE.fields_by_name['status'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['developer'])
_SUBSCRIBE.fields_by_name['developer'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
_EVENT_DEVELOPER.containing_type = _EVENT
_EVENT.fields_by_name['point_cloud'].message_type = blickfeld_dot_data_dot_point__cloud__pb2._POINTCLOUD
_EVENT.fields_by_name['status'].message_type = blickfeld_dot_status_dot_main__pb2._STATUS
_EVENT.fields_by_name['developer'].message_type = _EVENT_DEVELOPER
_EVENT.oneofs_by_name['data'].fields.append(
  _EVENT.fields_by_name['point_cloud'])
_EVENT.fields_by_name['point_cloud'].containing_oneof = _EVENT.oneofs_by_name['data']
_EVENT.oneofs_by_name['data'].fields.append(
  _EVENT.fields_by_name['status'])
_EVENT.fields_by_name['status'].containing_oneof = _EVENT.oneofs_by_name['data']
_EVENT.oneofs_by_name['data'].fields.append(
  _EVENT.fields_by_name['developer'])
_EVENT.fields_by_name['developer'].containing_oneof = _EVENT.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['Subscribe'] = _SUBSCRIBE
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Subscribe = _reflection.GeneratedProtocolMessageType('Subscribe', (_message.Message,), dict(

  PointCloud = _reflection.GeneratedProtocolMessageType('PointCloud', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_POINTCLOUD,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.PointCloud)
    ))
  ,

  Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_STATUS,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.Status)
    ))
  ,

  Developer = _reflection.GeneratedProtocolMessageType('Developer', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_DEVELOPER,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.Developer)
    ))
  ,
  DESCRIPTOR = _SUBSCRIBE,
  __module__ = 'blickfeld.stream.connection_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe)
  ))
_sym_db.RegisterMessage(Subscribe)
_sym_db.RegisterMessage(Subscribe.PointCloud)
_sym_db.RegisterMessage(Subscribe.Status)
_sym_db.RegisterMessage(Subscribe.Developer)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), dict(

  Developer = _reflection.GeneratedProtocolMessageType('Developer', (_message.Message,), dict(
    DESCRIPTOR = _EVENT_DEVELOPER,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Event.Developer)
    ))
  ,
  DESCRIPTOR = _EVENT,
  __module__ = 'blickfeld.stream.connection_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Event)
  ))
_sym_db.RegisterMessage(Event)
_sym_db.RegisterMessage(Event.Developer)


_EVENT.oneofs_by_name['data']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/data/frame.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2
from ..data import scanline_pb2 as blickfeld_dot_data_dot_scanline__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/data/frame.proto',
  package='blickfeld.protocol.data',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1a\x62lickfeld/data/frame.proto\x12\x17\x62lickfeld.protocol.data\x1a#blickfeld/config/scan_pattern.proto\x1a\x1d\x62lickfeld/data/scanline.proto\"\xdf\x01\n\x05\x46rame\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x34\n\tscanlines\x18\x02 \x03(\x0b\x32!.blickfeld.protocol.data.Scanline\x12\x15\n\rstart_time_ns\x18\x03 \x01(\x04\x12<\n\x0cscan_pattern\x18\x05 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPattern\x12\x1e\n\x16total_number_of_points\x18\x06 \x01(\r\x12\x1f\n\x17total_number_of_returns\x18\x07 \x01(\r')
  ,
  dependencies=[blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,blickfeld_dot_data_dot_scanline__pb2.DESCRIPTOR,])




_FRAME = _descriptor.Descriptor(
  name='Frame',
  full_name='blickfeld.protocol.data.Frame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blickfeld.protocol.data.Frame.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanlines', full_name='blickfeld.protocol.data.Frame.scanlines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time_ns', full_name='blickfeld.protocol.data.Frame.start_time_ns', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scan_pattern', full_name='blickfeld.protocol.data.Frame.scan_pattern', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_number_of_points', full_name='blickfeld.protocol.data.Frame.total_number_of_points', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_number_of_returns', full_name='blickfeld.protocol.data.Frame.total_number_of_returns', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=347,
)

_FRAME.fields_by_name['scanlines'].message_type = blickfeld_dot_data_dot_scanline__pb2._SCANLINE
_FRAME.fields_by_name['scan_pattern'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
DESCRIPTOR.message_types_by_name['Frame'] = _FRAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Frame = _reflection.GeneratedProtocolMessageType('Frame', (_message.Message,), dict(
  DESCRIPTOR = _FRAME,
  __module__ = 'blickfeld.data.frame_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.Frame)
  ))
_sym_db.RegisterMessage(Frame)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/config/scan_pattern.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/config/scan_pattern.proto',
  package='blickfeld.protocol.config',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n#blickfeld/config/scan_pattern.proto\x12\x19\x62lickfeld.protocol.config\x1a\x17\x62lickfeld/options.proto\"\x9a\x07\n\x0bScanPattern\x12\x45\n\nhorizontal\x18\x01 \x01(\x0b\x32\x31.blickfeld.protocol.config.ScanPattern.Horizontal\x12\x41\n\x08vertical\x18\x02 \x01(\x0b\x32/.blickfeld.protocol.config.ScanPattern.Vertical\x12;\n\x05pulse\x18\x03 \x01(\x0b\x32,.blickfeld.protocol.config.ScanPattern.Pulse\x12\x44\n\nframe_rate\x18\x04 \x01(\x0b\x32\x30.blickfeld.protocol.config.ScanPattern.FrameRate\x1a\x19\n\nHorizontal\x12\x0b\n\x03\x66ov\x18\x01 \x01(\x02\x1ah\n\x08Vertical\x12\x0b\n\x03\x66ov\x18\x01 \x01(\x02\x12&\n\x0cscanlines_up\x18\x02 \x01(\r:\x03\x32\x30\x30\x42\x0b\x81\xb5\x18\x00\x00\x00\x00\x00\x00\xf0?\x12\'\n\x0escanlines_down\x18\x03 \x01(\r:\x02\x33\x30\x42\x0b\x81\xb5\x18\x00\x00\x00\x00\x00\x00\xf0?\x1a\x90\x03\n\x05Pulse\x12\x15\n\rangle_spacing\x18\x02 \x01(\x02\x12V\n\x04type\x18\x03 \x01(\x0e\x32\x31.blickfeld.protocol.config.ScanPattern.Pulse.Type:\x15\x45QUI_HORIZONTAL_ANGLE\x12S\n\nframe_mode\x18\x04 \x01(\x0e\x32\x36.blickfeld.protocol.config.ScanPattern.Pulse.FrameMode:\x07ONLY_UP\x12#\n\x15\x64istortion_correction\x18\x05 \x01(\x08:\x04true\"3\n\x04Type\x12\x19\n\x15\x45QUI_HORIZONTAL_ANGLE\x10\x00\x12\x10\n\x0c\x45QUI_DENSITY\x10\x01\"T\n\tFrameMode\x12\x08\n\x04NONE\x10\x00\x12\x13\n\x0f\x43OMBINE_UP_DOWN\x10\x01\x12\x0b\n\x07ONLY_UP\x10\x02\x12\r\n\tONLY_DOWN\x10\x03\x12\x0c\n\x08SEPARATE\x10\x04*\x04\x08\x01\x10\x02*\x04\x08\x06\x10\x07R\x07padding\x1aZ\n\tFrameRate\x12\x14\n\x06target\x18\x01 \x01(\x01\x42\x04\xb0\xb5\x18\x01\x12\x15\n\x07maximum\x18\x02 \x01(\x01\x42\x04\xb0\xb5\x18\x01\x12 \n\x15reference_time_offset\x18\x03 \x01(\x01:\x01\x30*\x04\x08\x05\x10\x06*\x04\x08\x06\x10\x07')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,])



_SCANPATTERN_PULSE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUI_HORIZONTAL_ANGLE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUI_DENSITY', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=752,
  serialized_end=803,
)
_sym_db.RegisterEnumDescriptor(_SCANPATTERN_PULSE_TYPE)

_SCANPATTERN_PULSE_FRAMEMODE = _descriptor.EnumDescriptor(
  name='FrameMode',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.FrameMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMBINE_UP_DOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONLY_UP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONLY_DOWN', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEPARATE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=805,
  serialized_end=889,
)
_sym_db.RegisterEnumDescriptor(_SCANPATTERN_PULSE_FRAMEMODE)


_SCANPATTERN_HORIZONTAL = _descriptor.Descriptor(
  name='Horizontal',
  full_name='blickfeld.protocol.config.ScanPattern.Horizontal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fov', full_name='blickfeld.protocol.config.ScanPattern.Horizontal.fov', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=401,
)

_SCANPATTERN_VERTICAL = _descriptor.Descriptor(
  name='Vertical',
  full_name='blickfeld.protocol.config.ScanPattern.Vertical',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fov', full_name='blickfeld.protocol.config.ScanPattern.Vertical.fov', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanlines_up', full_name='blickfeld.protocol.config.ScanPattern.Vertical.scanlines_up', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=200,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\201\265\030\000\000\000\000\000\000\360?'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanlines_down', full_name='blickfeld.protocol.config.ScanPattern.Vertical.scanlines_down', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=30,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\201\265\030\000\000\000\000\000\000\360?'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=507,
)

_SCANPATTERN_PULSE = _descriptor.Descriptor(
  name='Pulse',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle_spacing', full_name='blickfeld.protocol.config.ScanPattern.Pulse.angle_spacing', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='blickfeld.protocol.config.ScanPattern.Pulse.type', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_mode', full_name='blickfeld.protocol.config.ScanPattern.Pulse.frame_mode', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distortion_correction', full_name='blickfeld.protocol.config.ScanPattern.Pulse.distortion_correction', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCANPATTERN_PULSE_TYPE,
    _SCANPATTERN_PULSE_FRAMEMODE,
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 2), (6, 7), ],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=910,
)

_SCANPATTERN_FRAMERATE = _descriptor.Descriptor(
  name='FrameRate',
  full_name='blickfeld.protocol.config.ScanPattern.FrameRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='blickfeld.protocol.config.ScanPattern.FrameRate.target', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='blickfeld.protocol.config.ScanPattern.FrameRate.maximum', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_time_offset', full_name='blickfeld.protocol.config.ScanPattern.FrameRate.reference_time_offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=1002,
)

_SCANPATTERN = _descriptor.Descriptor(
  name='ScanPattern',
  full_name='blickfeld.protocol.config.ScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizontal', full_name='blickfeld.protocol.config.ScanPattern.horizontal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical', full_name='blickfeld.protocol.config.ScanPattern.vertical', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pulse', full_name='blickfeld.protocol.config.ScanPattern.pulse', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_rate', full_name='blickfeld.protocol.config.ScanPattern.frame_rate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SCANPATTERN_HORIZONTAL, _SCANPATTERN_VERTICAL, _SCANPATTERN_PULSE, _SCANPATTERN_FRAMERATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(5, 6), (6, 7), ],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=1014,
)

_SCANPATTERN_HORIZONTAL.containing_type = _SCANPATTERN
_SCANPATTERN_VERTICAL.containing_type = _SCANPATTERN
_SCANPATTERN_PULSE.fields_by_name['type'].enum_type = _SCANPATTERN_PULSE_TYPE
_SCANPATTERN_PULSE.fields_by_name['frame_mode'].enum_type = _SCANPATTERN_PULSE_FRAMEMODE
_SCANPATTERN_PULSE.containing_type = _SCANPATTERN
_SCANPATTERN_PULSE_TYPE.containing_type = _SCANPATTERN_PULSE
_SCANPATTERN_PULSE_FRAMEMODE.containing_type = _SCANPATTERN_PULSE
_SCANPATTERN_FRAMERATE.containing_type = _SCANPATTERN
_SCANPATTERN.fields_by_name['horizontal'].message_type = _SCANPATTERN_HORIZONTAL
_SCANPATTERN.fields_by_name['vertical'].message_type = _SCANPATTERN_VERTICAL
_SCANPATTERN.fields_by_name['pulse'].message_type = _SCANPATTERN_PULSE
_SCANPATTERN.fields_by_name['frame_rate'].message_type = _SCANPATTERN_FRAMERATE
DESCRIPTOR.message_types_by_name['ScanPattern'] = _SCANPATTERN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScanPattern = _reflection.GeneratedProtocolMessageType('ScanPattern', (_message.Message,), dict(

  Horizontal = _reflection.GeneratedProtocolMessageType('Horizontal', (_message.Message,), dict(
    DESCRIPTOR = _SCANPATTERN_HORIZONTAL,
    __module__ = 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Horizontal)
    ))
  ,

  Vertical = _reflection.GeneratedProtocolMessageType('Vertical', (_message.Message,), dict(
    DESCRIPTOR = _SCANPATTERN_VERTICAL,
    __module__ = 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Vertical)
    ))
  ,

  Pulse = _reflection.GeneratedProtocolMessageType('Pulse', (_message.Message,), dict(
    DESCRIPTOR = _SCANPATTERN_PULSE,
    __module__ = 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Pulse)
    ))
  ,

  FrameRate = _reflection.GeneratedProtocolMessageType('FrameRate', (_message.Message,), dict(
    DESCRIPTOR = _SCANPATTERN_FRAMERATE,
    __module__ = 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.FrameRate)
    ))
  ,
  DESCRIPTOR = _SCANPATTERN,
  __module__ = 'blickfeld.config.scan_pattern_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern)
  ))
_sym_db.RegisterMessage(ScanPattern)
_sym_db.RegisterMessage(ScanPattern.Horizontal)
_sym_db.RegisterMessage(ScanPattern.Vertical)
_sym_db.RegisterMessage(ScanPattern.Pulse)
_sym_db.RegisterMessage(ScanPattern.FrameRate)


_SCANPATTERN_VERTICAL.fields_by_name['scanlines_up']._options = None
_SCANPATTERN_VERTICAL.fields_by_name['scanlines_down']._options = None
_SCANPATTERN_FRAMERATE.fields_by_name['target']._options = None
_SCANPATTERN_FRAMERATE.fields_by_name['maximum']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/connection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as blickfeld_dot_options__pb2
from . import error_pb2 as blickfeld_dot_error__pb2
from .config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2
from .stream import connection_pb2 as blickfeld_dot_stream_dot_connection__pb2
from .status import main_pb2 as blickfeld_dot_status_dot_main__pb2
from .config import secure_pb2 as blickfeld_dot_config_dot_secure__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/connection.proto',
  package='blickfeld.protocol',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1a\x62lickfeld/connection.proto\x12\x12\x62lickfeld.protocol\x1a\x17\x62lickfeld/options.proto\x1a\x15\x62lickfeld/error.proto\x1a#blickfeld/config/scan_pattern.proto\x1a!blickfeld/stream/connection.proto\x1a\x1b\x62lickfeld/status/main.proto\x1a\x1d\x62lickfeld/config/secure.proto\"\xc9\x07\n\x07Request\x12\x32\n\x05hello\x18\x0b \x01(\x0b\x32!.blickfeld.protocol.Request.HelloH\x00\x12:\n\tdeveloper\x18\r \x01(\x0b\x32%.blickfeld.protocol.Request.DeveloperH\x00\x12\x46\n\x10set_scan_pattern\x18\x0f \x01(\x0b\x32*.blickfeld.protocol.Request.SetScanPatternH\x00\x12H\n\x11\x66ill_scan_pattern\x18\x10 \x01(\x0b\x32+.blickfeld.protocol.Request.FillScanPatternH\x00\x12\x46\n\x10get_scan_pattern\x18\x11 \x01(\x0b\x32*.blickfeld.protocol.Request.GetScanPatternH\x00\x12\x39\n\tsubscribe\x18\x12 \x01(\x0b\x32$.blickfeld.protocol.stream.SubscribeH\x00\x12\x34\n\x06status\x18\x13 \x01(\x0b\x32\".blickfeld.protocol.Request.StatusH\x00\x12\x11\n\x07_asJSON\x18\x64 \x01(\tH\x00\x12;\n\raccept_format\x18\x65 \x01(\x0e\x32\x1a.blickfeld.protocol.Format:\x08PROTOBUF\x1a!\n\x05Hello\x12\x18\n\x10protocol_version\x18\x01 \x01(\r\x1a\x1f\n\tDeveloper*\x08\x08\x01\x10\x80\x80\x80\x80\x02:\x08\x92\xa6\x1d\x04\x08\x01\x10\x00\x1a\xab\x01\n\x0eSetScanPattern\x12<\n\x06\x63onfig\x18\x03 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xd0\xb5\x18\x01\x12\x16\n\x07persist\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x43\n\rlegacy_config\x18\x01 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xb0\xb5\x18\x01\x1a\x9c\x01\n\x0f\x46illScanPattern\x12@\n\x06\x63onfig\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x08\xb8\xb5\x18\x01\xd0\xb5\x18\x01\x12G\n\rlegacy_config\x18\x01 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x08\xb8\xb5\x18\x01\xb0\xb5\x18\x01\x1a\x10\n\x0eGetScanPattern\x1a\x08\n\x06StatusB\x06\n\x04\x64\x61ta\"\x98\x07\n\x08Response\x12\x14\n\x0ctimestamp_ns\x18\x01 \x01(\x04\x12*\n\x05\x65rror\x18\n \x01(\x0b\x32\x19.blickfeld.protocol.ErrorH\x00\x12\x33\n\x05hello\x18\x0b \x01(\x0b\x32\".blickfeld.protocol.Response.HelloH\x00\x12;\n\tdeveloper\x18\r \x01(\x0b\x32&.blickfeld.protocol.Response.DeveloperH\x00\x12G\n\x10set_scan_pattern\x18\x0f \x01(\x0b\x32+.blickfeld.protocol.Response.SetScanPatternH\x00\x12I\n\x11\x66ill_scan_pattern\x18\x10 \x01(\x0b\x32,.blickfeld.protocol.Response.FillScanPatternH\x00\x12G\n\x10get_scan_pattern\x18\x11 \x01(\x0b\x32+.blickfeld.protocol.Response.GetScanPatternH\x00\x12\x31\n\x05\x65vent\x18\x12 \x01(\x0b\x32 .blickfeld.protocol.stream.EventH\x00\x12,\n\x06status\x18\x13 \x01(\x0b\x32\x1a.blickfeld.protocol.StatusH\x00\x12\x11\n\x07_asJSON\x18\x64 \x01(\tH\x00\x1a!\n\x05Hello\x12\x18\n\x10protocol_version\x18\x01 \x01(\r\x1a\x15\n\tDeveloper*\x08\x08\x01\x10\x80\x80\x80\x80\x02\x1a\x10\n\x0eSetScanPattern\x1a\x9c\x01\n\x0f\x46illScanPattern\x12<\n\x06\x63onfig\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xd0\xb5\x18\x01\x12\x43\n\rlegacy_config\x18\x01 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xb0\xb5\x18\x01:\x06\x8a\xa6\x1d\x02..\x1a\x93\x01\n\x0eGetScanPattern\x12<\n\x06\x63onfig\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xd0\xb5\x18\x01\x12\x43\n\rlegacy_config\x18\x01 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xb0\xb5\x18\x01\x42\x06\n\x04\x64\x61ta* \n\x06\x46ormat\x12\x0c\n\x08PROTOBUF\x10\x01\x12\x08\n\x04JSON\x10\x02')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_error__pb2.DESCRIPTOR,blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,blickfeld_dot_stream_dot_connection__pb2.DESCRIPTOR,blickfeld_dot_status_dot_main__pb2.DESCRIPTOR,blickfeld_dot_config_dot_secure__pb2.DESCRIPTOR,])

_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='blickfeld.protocol.Format',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROTOBUF', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2125,
  serialized_end=2157,
)
_sym_db.RegisterEnumDescriptor(_FORMAT)

Format = enum_type_wrapper.EnumTypeWrapper(_FORMAT)
PROTOBUF = 1
JSON = 2



_REQUEST_HELLO = _descriptor.Descriptor(
  name='Hello',
  full_name='blickfeld.protocol.Request.Hello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='blickfeld.protocol.Request.Hello.protocol_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=798,
)

_REQUEST_DEVELOPER = _descriptor.Descriptor(
  name='Developer',
  full_name='blickfeld.protocol.Request.Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\222\246\035\004\010\001\020\000'),
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=831,
)

_REQUEST_SETSCANPATTERN = _descriptor.Descriptor(
  name='SetScanPattern',
  full_name='blickfeld.protocol.Request.SetScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='blickfeld.protocol.Request.SetScanPattern.config', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\320\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persist', full_name='blickfeld.protocol.Request.SetScanPattern.persist', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_config', full_name='blickfeld.protocol.Request.SetScanPattern.legacy_config', index=2,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=1005,
)

_REQUEST_FILLSCANPATTERN = _descriptor.Descriptor(
  name='FillScanPattern',
  full_name='blickfeld.protocol.Request.FillScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='blickfeld.protocol.Request.FillScanPattern.config', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\270\265\030\001\320\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_config', full_name='blickfeld.protocol.Request.FillScanPattern.legacy_config', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\270\265\030\001\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1164,
)

_REQUEST_GETSCANPATTERN = _descriptor.Descriptor(
  name='GetScanPattern',
  full_name='blickfeld.protocol.Request.GetScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1166,
  serialized_end=1182,
)

_REQUEST_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='blickfeld.protocol.Request.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1192,
)

_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='blickfeld.protocol.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hello', full_name='blickfeld.protocol.Request.hello', index=0,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='blickfeld.protocol.Request.developer', index=1,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_scan_pattern', full_name='blickfeld.protocol.Request.set_scan_pattern', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_scan_pattern', full_name='blickfeld.protocol.Request.fill_scan_pattern', index=3,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_scan_pattern', full_name='blickfeld.protocol.Request.get_scan_pattern', index=4,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribe', full_name='blickfeld.protocol.Request.subscribe', index=5,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='blickfeld.protocol.Request.status', index=6,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='_asJSON', full_name='blickfeld.protocol.Request._asJSON', index=7,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accept_format', full_name='blickfeld.protocol.Request.accept_format', index=8,
      number=101, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REQUEST_HELLO, _REQUEST_DEVELOPER, _REQUEST_SETSCANPATTERN, _REQUEST_FILLSCANPATTERN, _REQUEST_GETSCANPATTERN, _REQUEST_STATUS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.Request.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=231,
  serialized_end=1200,
)


_RESPONSE_HELLO = _descriptor.Descriptor(
  name='Hello',
  full_name='blickfeld.protocol.Response.Hello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='blickfeld.protocol.Response.Hello.protocol_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=798,
)

_RESPONSE_DEVELOPER = _descriptor.Descriptor(
  name='Developer',
  full_name='blickfeld.protocol.Response.Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=821,
)

_RESPONSE_SETSCANPATTERN = _descriptor.Descriptor(
  name='SetScanPattern',
  full_name='blickfeld.protocol.Response.SetScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=850,
)

_RESPONSE_FILLSCANPATTERN = _descriptor.Descriptor(
  name='FillScanPattern',
  full_name='blickfeld.protocol.Response.FillScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='blickfeld.protocol.Response.FillScanPattern.config', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\320\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_config', full_name='blickfeld.protocol.Response.FillScanPattern.legacy_config', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\212\246\035\002..'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1809,
  serialized_end=1965,
)

_RESPONSE_GETSCANPATTERN = _descriptor.Descriptor(
  name='GetScanPattern',
  full_name='blickfeld.protocol.Response.GetScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='blickfeld.protocol.Response.GetScanPattern.config', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\320\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_config', full_name='blickfeld.protocol.Response.GetScanPattern.legacy_config', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1968,
  serialized_end=2115,
)

_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='blickfeld.protocol.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_ns', full_name='blickfeld.protocol.Response.timestamp_ns', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='blickfeld.protocol.Response.error', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hello', full_name='blickfeld.protocol.Response.hello', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='blickfeld.protocol.Response.developer', index=3,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_scan_pattern', full_name='blickfeld.protocol.Response.set_scan_pattern', index=4,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_scan_pattern', full_name='blickfeld.protocol.Response.fill_scan_pattern', index=5,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_scan_pattern', full_name='blickfeld.protocol.Response.get_scan_pattern', index=6,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event', full_name='blickfeld.protocol.Response.event', index=7,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='blickfeld.protocol.Response.status', index=8,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='_asJSON', full_name='blickfeld.protocol.Response._asJSON', index=9,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RESPONSE_HELLO, _RESPONSE_DEVELOPER, _RESPONSE_SETSCANPATTERN, _RESPONSE_FILLSCANPATTERN, _RESPONSE_GETSCANPATTERN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.Response.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1203,
  serialized_end=2123,
)

_REQUEST_HELLO.containing_type = _REQUEST
_REQUEST_DEVELOPER.containing_type = _REQUEST
_REQUEST_SETSCANPATTERN.fields_by_name['config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_REQUEST_SETSCANPATTERN.fields_by_name['legacy_config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_REQUEST_SETSCANPATTERN.containing_type = _REQUEST
_REQUEST_FILLSCANPATTERN.fields_by_name['config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_REQUEST_FILLSCANPATTERN.fields_by_name['legacy_config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_REQUEST_FILLSCANPATTERN.containing_type = _REQUEST
_REQUEST_GETSCANPATTERN.containing_type = _REQUEST
_REQUEST_STATUS.containing_type = _REQUEST
_REQUEST.fields_by_name['hello'].message_type = _REQUEST_HELLO
_REQUEST.fields_by_name['developer'].message_type = _REQUEST_DEVELOPER
_REQUEST.fields_by_name['set_scan_pattern'].message_type = _REQUEST_SETSCANPATTERN
_REQUEST.fields_by_name['fill_scan_pattern'].message_type = _REQUEST_FILLSCANPATTERN
_REQUEST.fields_by_name['get_scan_pattern'].message_type = _REQUEST_GETSCANPATTERN
_REQUEST.fields_by_name['subscribe'].message_type = blickfeld_dot_stream_dot_connection__pb2._SUBSCRIBE
_REQUEST.fields_by_name['status'].message_type = _REQUEST_STATUS
_REQUEST.fields_by_name['accept_format'].enum_type = _FORMAT
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['hello'])
_REQUEST.fields_by_name['hello'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['developer'])
_REQUEST.fields_by_name['developer'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['set_scan_pattern'])
_REQUEST.fields_by_name['set_scan_pattern'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['fill_scan_pattern'])
_REQUEST.fields_by_name['fill_scan_pattern'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['get_scan_pattern'])
_REQUEST.fields_by_name['get_scan_pattern'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['subscribe'])
_REQUEST.fields_by_name['subscribe'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['status'])
_REQUEST.fields_by_name['status'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['_asJSON'])
_REQUEST.fields_by_name['_asJSON'].containing_oneof = _REQUEST.oneofs_by_name['data']
_RESPONSE_HELLO.containing_type = _RESPONSE
_RESPONSE_DEVELOPER.containing_type = _RESPONSE
_RESPONSE_SETSCANPATTERN.containing_type = _RESPONSE
_RESPONSE_FILLSCANPATTERN.fields_by_name['config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_RESPONSE_FILLSCANPATTERN.fields_by_name['legacy_config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_RESPONSE_FILLSCANPATTERN.containing_type = _RESPONSE
_RESPONSE_GETSCANPATTERN.fields_by_name['config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_RESPONSE_GETSCANPATTERN.fields_by_name['legacy_config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_RESPONSE_GETSCANPATTERN.containing_type = _RESPONSE
_RESPONSE.fields_by_name['error'].message_type = blickfeld_dot_error__pb2._ERROR
_RESPONSE.fields_by_name['hello'].message_type = _RESPONSE_HELLO
_RESPONSE.fields_by_name['developer'].message_type = _RESPONSE_DEVELOPER
_RESPONSE.fields_by_name['set_scan_pattern'].message_type = _RESPONSE_SETSCANPATTERN
_RESPONSE.fields_by_name['fill_scan_pattern'].message_type = _RESPONSE_FILLSCANPATTERN
_RESPONSE.fields_by_name['get_scan_pattern'].message_type = _RESPONSE_GETSCANPATTERN
_RESPONSE.fields_by_name['event'].message_type = blickfeld_dot_stream_dot_connection__pb2._EVENT
_RESPONSE.fields_by_name['status'].message_type = blickfeld_dot_status_dot_main__pb2._STATUS
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['error'])
_RESPONSE.fields_by_name['error'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['hello'])
_RESPONSE.fields_by_name['hello'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['developer'])
_RESPONSE.fields_by_name['developer'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['set_scan_pattern'])
_RESPONSE.fields_by_name['set_scan_pattern'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['fill_scan_pattern'])
_RESPONSE.fields_by_name['fill_scan_pattern'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['get_scan_pattern'])
_RESPONSE.fields_by_name['get_scan_pattern'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['event'])
_RESPONSE.fields_by_name['event'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['status'])
_RESPONSE.fields_by_name['status'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['_asJSON'])
_RESPONSE.fields_by_name['_asJSON'].containing_oneof = _RESPONSE.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.enum_types_by_name['Format'] = _FORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), dict(

  Hello = _reflection.GeneratedProtocolMessageType('Hello', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_HELLO,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.Hello)
    ))
  ,

  Developer = _reflection.GeneratedProtocolMessageType('Developer', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_DEVELOPER,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.Developer)
    ))
  ,

  SetScanPattern = _reflection.GeneratedProtocolMessageType('SetScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_SETSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.SetScanPattern)
    ))
  ,

  FillScanPattern = _reflection.GeneratedProtocolMessageType('FillScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_FILLSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.FillScanPattern)
    ))
  ,

  GetScanPattern = _reflection.GeneratedProtocolMessageType('GetScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_GETSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.GetScanPattern)
    ))
  ,

  Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_STATUS,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.Status)
    ))
  ,
  DESCRIPTOR = _REQUEST,
  __module__ = 'blickfeld.connection_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request)
  ))
_sym_db.RegisterMessage(Request)
_sym_db.RegisterMessage(Request.Hello)
_sym_db.RegisterMessage(Request.Developer)
_sym_db.RegisterMessage(Request.SetScanPattern)
_sym_db.RegisterMessage(Request.FillScanPattern)
_sym_db.RegisterMessage(Request.GetScanPattern)
_sym_db.RegisterMessage(Request.Status)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(

  Hello = _reflection.GeneratedProtocolMessageType('Hello', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_HELLO,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.Hello)
    ))
  ,

  Developer = _reflection.GeneratedProtocolMessageType('Developer', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_DEVELOPER,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.Developer)
    ))
  ,

  SetScanPattern = _reflection.GeneratedProtocolMessageType('SetScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_SETSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.SetScanPattern)
    ))
  ,

  FillScanPattern = _reflection.GeneratedProtocolMessageType('FillScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_FILLSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.FillScanPattern)
    ))
  ,

  GetScanPattern = _reflection.GeneratedProtocolMessageType('GetScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_GETSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.GetScanPattern)
    ))
  ,
  DESCRIPTOR = _RESPONSE,
  __module__ = 'blickfeld.connection_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response)
  ))
_sym_db.RegisterMessage(Response)
_sym_db.RegisterMessage(Response.Hello)
_sym_db.RegisterMessage(Response.Developer)
_sym_db.RegisterMessage(Response.SetScanPattern)
_sym_db.RegisterMessage(Response.FillScanPattern)
_sym_db.RegisterMessage(Response.GetScanPattern)


_REQUEST_DEVELOPER._options = None
_REQUEST_SETSCANPATTERN.fields_by_name['config']._options = None
_REQUEST_SETSCANPATTERN.fields_by_name['legacy_config']._options = None
_REQUEST_FILLSCANPATTERN.fields_by_name['config']._options = None
_REQUEST_FILLSCANPATTERN.fields_by_name['legacy_config']._options = None
_RESPONSE_FILLSCANPATTERN.fields_by_name['config']._options = None
_RESPONSE_FILLSCANPATTERN.fields_by_name['legacy_config']._options = None
_RESPONSE_FILLSCANPATTERN._options = None
_RESPONSE_GETSCANPATTERN.fields_by_name['config']._options = None
_RESPONSE_GETSCANPATTERN.fields_by_name['legacy_config']._options = None
# @@protoc_insertion_point(module_scope)
